@@ -35,8 +35,9 @@ Usage::
     ```
 """
 from datetime import datetime
-from typing import Iterator, Union
+from typing import Generic, Iterator, TypeVar, Union
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import (
@@ -72,9 +73,19 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class DescribeActivitiesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
     """
 
@@ -90,16 +101,16 @@ class DescribeActivitiesPaginator(Boto3Paginator):
         UserId: str = None,
         IncludeIndirectActivities: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeActivitiesResponseTypeDef]:
+    ) -> _PageIterator[DescribeActivitiesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
         """
 
 
 class DescribeCommentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
     """
 
@@ -110,16 +121,16 @@ class DescribeCommentsPaginator(Boto3Paginator):
         VersionId: str,
         AuthenticationToken: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeCommentsResponseTypeDef]:
+    ) -> _PageIterator[DescribeCommentsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
         """
 
 
 class DescribeDocumentVersionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
     """
 
@@ -131,16 +142,16 @@ class DescribeDocumentVersionsPaginator(Boto3Paginator):
         Include: str = None,
         Fields: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeDocumentVersionsResponseTypeDef]:
+    ) -> _PageIterator[DescribeDocumentVersionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
         """
 
 
 class DescribeFolderContentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
     """
 
@@ -154,16 +165,16 @@ class DescribeFolderContentsPaginator(Boto3Paginator):
         Type: FolderContentTypeType = None,
         Include: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeFolderContentsResponseTypeDef]:
+    ) -> _PageIterator[DescribeFolderContentsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
         """
 
 
 class DescribeGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
     """
 
@@ -174,31 +185,31 @@ class DescribeGroupsPaginator(Boto3Paginator):
         AuthenticationToken: str = None,
         OrganizationId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeGroupsResponseTypeDef]:
+    ) -> _PageIterator[DescribeGroupsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
         """
 
 
 class DescribeNotificationSubscriptionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
     """
 
     def paginate(
         self, *, OrganizationId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeNotificationSubscriptionsResponseTypeDef]:
+    ) -> _PageIterator[DescribeNotificationSubscriptionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
         """
 
 
 class DescribeResourcePermissionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
     """
 
@@ -209,31 +220,31 @@ class DescribeResourcePermissionsPaginator(Boto3Paginator):
         AuthenticationToken: str = None,
         PrincipalId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeResourcePermissionsResponseTypeDef]:
+    ) -> _PageIterator[DescribeResourcePermissionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
         """
 
 
 class DescribeRootFoldersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
     """
 
     def paginate(
         self, *, AuthenticationToken: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeRootFoldersResponseTypeDef]:
+    ) -> _PageIterator[DescribeRootFoldersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
         """
 
 
 class DescribeUsersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
     """
 
@@ -249,8 +260,8 @@ class DescribeUsersPaginator(Boto3Paginator):
         Sort: UserSortTypeType = None,
         Fields: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeUsersResponseTypeDef]:
+    ) -> _PageIterator[DescribeUsersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
         """
